@@ -8,13 +8,16 @@ Perlanet::Trait::FeedFile - save the aggregated feed to a file
 
 =head1 SYNOPSIS
 
-   my $perlanet = Perlanet->new_with_traits(traits => [ 'Perlanet::Trait::FeedFile' ]);
-   $perlanet->run
+   my $perlanet = Perlanet->new_with_traits(
+     traits => [ 'Perlanet::Trait::FeedFile' ]
+   );
+
+   $perlanet->run;
 
 =head1 DESCRIPTION
 
-When the aggregation is complete and the feed is being rendered, it will be saved to
-disk in XML format.
+When the aggregation is complete and the feed is being rendered, it will be
+saved to disk in XML format.
 
 =head1 ATTRIBUTES
 
@@ -31,26 +34,22 @@ The format of the XML to use - may be RSS or Atom
 use Carp qw( croak );
 use Template;
 
-has 'feed_file' => (
-    isa       => 'Str',
-    is        => 'rw',
-    predicate => 'has_feed_file',
-);
-
-has 'feed_format' => (
-    isa     => 'Str',
-    is      => 'rw',
-    default => 'RSS',
+has 'feed' => (
+  isa       => 'HashRef',
+  is        => 'rw',
+  default   => sub {
+    { file => 'atom.xml', format => 'Atom' }
+  },
 );
 
 after 'render' => sub {
-    my ($self, $feed) = @_;
-    return unless $self->has_feed_file;
+  my ($self, $feed) = @_;
+  return unless $self->feed->{file};
 
-    open my $feedfile, '>', $self->feed_file
-        or croak 'Cannot open ' . $self->feed_file . " for writing: $!";
-    print $feedfile $feed->as_xml($self->feed_format);
-    close $feedfile;
+  open my $feedfile, '>', $self->feed->{file}
+    or croak 'Cannot open ' . $self->feed->{file} . " for writing: $!";
+  print $feedfile $feed->as_xml($self->feed->{format});
+  close $feedfile;
 };
 
 =head1 AUTHOR
@@ -59,7 +58,7 @@ Oliver Charles, <oliver.g.charles@googlemail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008 by Magnum Solutions Ltd.
+Copyright (c) 2010 by Magnum Solutions Ltd.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
